[PATCH] drm: flip-work: rename commited -> committed

Colin Ian King colin.i.king at gmail.com
Thu Jul 14 12:56:01 UTC 2022


There is a spelling mistake in the list head variable, rename it.

Signed-off-by: Colin Ian King <colin.i.king at gmail.com>
---
 drivers/gpu/drm/drm_flip_work.c | 10 +++++-----
 include/drm/drm_flip_work.h     |  6 +++---
 2 files changed, 8 insertions(+), 8 deletions(-)

diff --git a/drivers/gpu/drm/drm_flip_work.c b/drivers/gpu/drm/drm_flip_work.c
index 060b753881a2..8efb5f2c5773 100644
--- a/drivers/gpu/drm/drm_flip_work.c
+++ b/drivers/gpu/drm/drm_flip_work.c
@@ -104,7 +104,7 @@ void drm_flip_work_commit(struct drm_flip_work *work,
 	unsigned long flags;
 
 	spin_lock_irqsave(&work->lock, flags);
-	list_splice_tail(&work->queued, &work->commited);
+	list_splice_tail(&work->queued, &work->committed);
 	INIT_LIST_HEAD(&work->queued);
 	spin_unlock_irqrestore(&work->lock, flags);
 	queue_work(wq, &work->worker);
@@ -122,8 +122,8 @@ static void flip_worker(struct work_struct *w)
 
 		INIT_LIST_HEAD(&tasks);
 		spin_lock_irqsave(&work->lock, flags);
-		list_splice_tail(&work->commited, &tasks);
-		INIT_LIST_HEAD(&work->commited);
+		list_splice_tail(&work->committed, &tasks);
+		INIT_LIST_HEAD(&work->committed);
 		spin_unlock_irqrestore(&work->lock, flags);
 
 		if (list_empty(&tasks))
@@ -149,7 +149,7 @@ void drm_flip_work_init(struct drm_flip_work *work,
 {
 	work->name = name;
 	INIT_LIST_HEAD(&work->queued);
-	INIT_LIST_HEAD(&work->commited);
+	INIT_LIST_HEAD(&work->committed);
 	spin_lock_init(&work->lock);
 	work->func = func;
 
@@ -165,6 +165,6 @@ EXPORT_SYMBOL(drm_flip_work_init);
  */
 void drm_flip_work_cleanup(struct drm_flip_work *work)
 {
-	WARN_ON(!list_empty(&work->queued) || !list_empty(&work->commited));
+	WARN_ON(!list_empty(&work->queued) || !list_empty(&work->committed));
 }
 EXPORT_SYMBOL(drm_flip_work_cleanup);
diff --git a/include/drm/drm_flip_work.h b/include/drm/drm_flip_work.h
index 21c3d512d25c..2e1342cdc568 100644
--- a/include/drm/drm_flip_work.h
+++ b/include/drm/drm_flip_work.h
@@ -67,15 +67,15 @@ struct drm_flip_task {
  * @func: callback fxn called for each committed item
  * @worker: worker which calls @func
  * @queued: queued tasks
  * @commited: commited tasks
  * @lock: lock to access queued and commited lists
  */
 struct drm_flip_work {
 	const char *name;
 	drm_flip_func_t func;
 	struct work_struct worker;
 	struct list_head queued;
-	struct list_head commited;
+	struct list_head committed;
 	spinlock_t lock;
 };
 
@@ -67,15 +67,15 @@ struct drm_flip_task {
  * @worker: worker which calls @func
  * @queued: queued tasks
- * @commited: commited tasks
- * @lock: lock to access queued and commited lists
+ * @committed: committed tasks
+ * @lock: lock to access queued and committed lists
  */
 struct drm_flip_work {
-- 
2.35.3



More information about the dri-devel mailing list